# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from typing import List

from .base_model import BaseModel
from .fragments import ProductFragment


class GetProducts(BaseModel):
    products: "GetProductsProducts"


class GetProductsProducts(BaseModel):
    edges: List["GetProductsProductsEdges"]


class GetProductsProductsEdges(BaseModel):
    node: "GetProductsProductsEdgesNode"


class GetProductsProductsEdgesNode(ProductFragment):
    pass


GetProducts.update_forward_refs()
GetProductsProducts.update_forward_refs()
GetProductsProductsEdges.update_forward_refs()
GetProductsProductsEdgesNode.update_forward_refs()
