# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimCustomerFragment


class ImportCustomer(BaseModel):
    import_customer: "ImportCustomerImportCustomer" = Field(alias="importCustomer")


class ImportCustomerImportCustomer(SlimCustomerFragment):
    pass


ImportCustomer.update_forward_refs()
ImportCustomerImportCustomer.update_forward_refs()
